@@ -1,4 +1,4 @@
-/* $Id: rc.c,v 1.46 2002/06/01 17:10:37 ukai Exp $ */
+/* $Id: rc.c,v 1.54 2002/10/28 17:09:29 ukai Exp $ */
 /* 
  * Initialization file etc.
  */
@@ -66,14 +66,14 @@ static char *config_file = NULL;
 #define CMT_ARGV_IS_URL  "scheme Τʤ URL Ȥߤʤ"
 #define CMT_TSELF        "target̤ξ_selfѤ"
 #define CMT_DISPLINK     "μưɽ"
-#ifdef USE_IMAGE
+#define CMT_DISPLINEINFO "ߤιֹɽ"
 #define CMT_DISP_IMAGE   "饤ɽ"
+#ifdef USE_IMAGE
 #define CMT_AUTO_IMAGE   "饤ưɤ߹"
 #define CMT_MAX_LOAD_IMAGE "ɤ߹߻κץ"
 #define CMT_EXT_IMAGE_VIEWER   "ӥ塼ɽ"
 #define CMT_IMAGE_SCALE  "Υ(%)"
 #define CMT_IMGDISPLAY   "ɽ뤿Υޥ"
-#define CMT_IMGSIZE      "礭뤿Υޥ"
 #endif
 #define CMT_MULTICOL     "ե̾Υޥɽ"
 #define CMT_ALT_ENTITY   "ƥƥ ASCII ɽɽ"
@@ -127,6 +127,7 @@ static char *config_file = NULL;
 #define CMT_EXTBRZ       "֥饦"
 #define CMT_EXTBRZ2      "֥饦2"
 #define CMT_EXTBRZ3      "֥饦3"
+#define CMT_PASSWDFILE	 "ѥɥե"
 #define CMT_FTPPASS      "FTPΥѥ(̤ϼʬmail addressȤ)"
 #ifdef FTPPASS_HOSTNAMEGEN
 #define CMT_FTPPASS_HOSTNAMEGEN	"FTPΥѥɤΥɥᥤ̾ư"
@@ -207,14 +208,14 @@ static char *config_file = NULL;
 #define CMT_ARGV_IS_URL  "Treat argument without scheme as URL"
 #define CMT_TSELF        "Use _self as default target"
 #define CMT_DISPLINK     "Display link URL automatically"
-#ifdef USE_IMAGE
+#define CMT_DISPLINEINFO "Display current line number"
 #define CMT_DISP_IMAGE   "Display inline images"
+#ifdef USE_IMAGE
 #define CMT_AUTO_IMAGE   "Load inline images automatically"
 #define CMT_MAX_LOAD_IMAGE "Maximum processes for parallel image loading"
 #define CMT_EXT_IMAGE_VIEWER   "Use external image viewer"
 #define CMT_IMAGE_SCALE  "Scale of image (%)"
 #define CMT_IMGDISPLAY   "External command to display image"
-#define CMT_IMGSIZE      "External command to get size of image"
 #endif
 #define CMT_MULTICOL     "Display file names in multi-column format"
 #define CMT_ALT_ENTITY   "Use ASCII equivalents to display entities"
@@ -268,6 +269,7 @@ static char *config_file = NULL;
 #define CMT_EXTBRZ       "External Browser"
 #define CMT_EXTBRZ2      "Second External Browser"
 #define CMT_EXTBRZ3      "Third External Browser"
+#define CMT_PASSWDFILE	 "Password file"
 #define CMT_FTPPASS      "Password for anonymous FTP (your mail address)"
 #ifdef FTPPASS_HOSTNAMEGEN
 #define CMT_FTPPASS_HOSTNAMEGEN "Generate domain part of password for FTP"
@@ -463,6 +465,8 @@ struct param_ptr params1[] = {
     {"target_self", P_CHARINT, PI_ONOFF, (void *)&TargetSelf, CMT_TSELF, NULL},
     {"display_link", P_INT, PI_ONOFF, (void *)&displayLink, CMT_DISPLINK,
      NULL},
+    {"display_lineinfo", P_INT, PI_ONOFF, (void *)&displayLineInfo,
+     CMT_DISPLINEINFO, NULL},
     {"ext_dirlist", P_INT, PI_ONOFF, (void *)&UseExternalDirBuffer,
      CMT_EXT_DIRLIST, NULL},
     {"dirlist_cmd", P_STRING, PI_TEXT, (void *)&DirBufferCommand,
@@ -482,9 +486,10 @@ struct param_ptr params1[] = {
      CMT_IGNORE_NULL_IMG_ALT, NULL},
     {"view_unseenobject", P_INT, PI_ONOFF, (void *)&view_unseenobject,
      CMT_VIEW_UNSEENOBJECTS, NULL},
-#ifdef USE_IMAGE
+    /* XXX: emacs-w3m force to off display_image even if image options off */
     {"display_image", P_INT, PI_ONOFF, (void *)&displayImage, CMT_DISP_IMAGE,
      NULL},
+#ifdef USE_IMAGE
     {"auto_image", P_INT, PI_ONOFF, (void *)&autoImage, CMT_AUTO_IMAGE, NULL},
     {"max_load_image", P_INT, PI_TEXT, (void *)&maxLoadImage,
      CMT_MAX_LOAD_IMAGE, NULL},
@@ -494,7 +499,6 @@ struct param_ptr params1[] = {
      NULL},
     {"imgdisplay", P_STRING, PI_TEXT, (void *)&Imgdisplay, CMT_IMGDISPLAY,
      NULL},
-    {"imgsize", P_STRING, PI_TEXT, (void *)&Imgsize, CMT_IMGSIZE, NULL},
 #endif
     {"show_lnum", P_INT, PI_ONOFF, (void *)&showLineNum, CMT_SHOW_NUM, NULL},
     {"show_srch_str", P_INT, PI_ONOFF, (void *)&show_srch_str,
@@ -666,6 +670,8 @@ struct param_ptr params8[] = {
 };
 #endif
 struct param_ptr params9[] = {
+    {"passwd_file", P_STRING, PI_TEXT, (void *)&passwd_file, CMT_PASSWDFILE,
+     NULL},
     {"ftppasswd", P_STRING, PI_TEXT, (void *)&ftppasswd, CMT_FTPPASS, NULL},
 #ifdef FTPPASS_HOSTNAMEGEN
     {"ftppass_hostnamegen", P_INT, PI_ONOFF, (void *)&ftppass_hostnamegen,
@@ -1230,13 +1236,16 @@ sync_with_option(void)
 #ifdef USE_IMAGE
     if (fmInitialized && displayImage)
 	initImage();
+#else
+    displayImage = FALSE;	/* XXX */
 #endif
+    loadPasswd();
 
     if (AcceptLang == NULL || *AcceptLang == '\0') {
 #if LANG == JA
-	AcceptLang = "ja; q=1.0, en; q=0.5";
+	AcceptLang = "ja;q=1.0, en;q=0.5";
 #else				/* LANG != JA (must be EN) */
-	AcceptLang = "en; q=1.0";
+	AcceptLang = "en;q=1.0";
 #endif
     }
     if (AcceptEncoding == NULL || *AcceptEncoding == '\0')
